Name:           votca-csg
Version:        1.3
Release:        4%{?_rcname}%{?dist}
Summary:        VOTCA coarse-graining engine
Group:          Applications/Engineering
License:        ASL 2.0
URL:            http://www.votca.org
Source0:        https://github.com/votca/csg/archive/v%{version}%{?_rc}.tar.gz
Patch0:         https://github.com/votca/csg/commit/34d55f6d771bcf026f453457f45d787391910598.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gromacs-devel
BuildRequires:  votca-tools-devel = %{version}
BuildRequires:  txt2tags

Requires:   %{name}-common = %{version}-%{release}
Requires:   %{name}-libs = %{version}-%{release}

%description
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the VOTCA coarse-graining engine.


%package libs
Summary:    Libraries for VOTCA coarse-graining engine
Group:      System Environment/Libraries

%description libs
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains libraries for the VOTCA coarse-graining engine.

%package devel
Summary:    Development headers and libraries for VOTCA coarse-graining Engine
Group:      Development/Libraries
Requires:   %{name}-libs = %{version}-%{release}
Requires:   votca-tools-devel

%description devel
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains development headers and libraries for the VOTCA
coarse-graining engine.

%package common
Summary:    Architecture independent data files for VOTCA
Group:      Applications/Engineering
BuildArch:  noarch

%description common
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains architecture independent data files for the VOTCA
coarse-graining engine.

%package bash
Summary:    Bash completion for votca
Group:      System Environment/Shells
Requires:   %{name} = %{version}-%{release}
Requires:   bash-completion
BuildArch:  noarch

%description bash
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package intended to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains bash completion support for the VOTCA coarse-graining
engine.


%prep
%setup -qn csg-%{version}%{?_rc}
%patch0 -p1

%build
mkdir %{_target_platform}
cd %{_target_platform}
# Get rid of -O3 in default flags
%{cmake} .. -DLIB=%{_lib} -DCMAKE_CXX_FLAGS_RELEASE="-DNDEBUG"
make %{?_smp_mflags}

%install
make -C %{_target_platform} install DESTDIR=%{buildroot} INSTALL="install -p"
# Install bash completion file
install -D -p -m 644 scripts/csg-completion.bash %{buildroot}%{_sysconfdir}/bash_completion.d/votca

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files
%doc NOTICE README.md CHANGELOG.md
%{_bindir}/csg_*
%{_bindir}/multi_g_*
%{_mandir}/man1/csg_*.1.*
%{_mandir}/man1/multi_g_*.1.*
%{_mandir}/man7/votca-csg.7.*

%files common
%{_datadir}/votca

%files libs
%license LICENSE
%{_libdir}/libvotca_csg.so.*

%files devel
%{_includedir}/votca/csg/
%{_libdir}/libvotca_csg.so
%{_libdir}/pkgconfig/libvotca_csg.pc

%files bash
%{_sysconfdir}/bash_completion.d/votca


%changelog
* Fri May 20 2016 Jonathan Wakely <jwakely@redhat.com> - 1.3-4
- Rebuilt for linker errors in boost (#1331983)

* Sun May 15 2016 Dominik Mierzejewski <rpm@greysector.net> - 1.3-3.1
- rebuild against new gromacs

* Fri Apr 01 2016 Dominik Mierzejewski <rpm@greysector.net> - 1.3-3
- rebuild for gromacs
- fix recent libgromacs_d detection using upstream patch

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3-2.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jan 24 2016 Thomas Spura <tomspur@fedoraproject.org> - 1.3-2
- Rebuilt for gromacs

* Tue Jan 19 2016 Christoph Junghans <junghans@votca.org> - 1.3-1
- update to 1.3
- cleanup spec

* Mon Nov 09 2015 Thomas Spura <tomspur@fedoraproject.org> - 1.3-0.1.rc1
- update to 1.3_rc1
- cleanup spec

* Thu Sep 03 2015 Jonathan Wakely <jwakely@redhat.com> - 1.2.4-10
- Rebuilt for Boost 1.59

* Sun Aug 30 2015 Thomas Spura <tomspur@fedoraproject.org> - 1.2.4-9
- Add another patch by Christoph Junghans to build with gromacs-5.1

* Fri Aug 28 2015 Jonathan Wakely <jwakely@redhat.com> - 1.2.4-8
- Rebuilt for Boost 1.59

* Fri Aug 21 2015 Thomas Spura <tomspur@fedoraproject.org> - 1.2.4-7
- Add patch by Christoph Junghans to build with gromacs-5.1

* Wed Aug 05 2015 Thomas Spura <tomspur@fedoraproject.org> - 1.2.4-6
- Rebuilt for new boost

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Apr 24 2015 Thomas Spura <tomspur@fedoraproject.org> - 1.2.4-4
- Rebuilt against new gromacs

* Thu Feb 05 2015 Thomas Spura <tomspur@fedoraproject.org> - 1.2.4-3
- Rebuilt for new boost

* Sun Sep  7 2014 Thomas Spura <tomspur@fedoraproject.org> - 1.2.4-2
- correct source url

* Fri Sep 05 2014 Christoph Junghans <junghans@votca.org> - 1.2.4-1
- Update to 1.2.4
- Drop obsolete patch

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 1.2.3-6
- rebuild for boost 1.55.0

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 28 2013 Petr Machata <pmachata@redhat.com> - 1.2.3-4
- Rebuild for boost 1.54.0

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.2.3-3
- Perl 5.18 rebuild

* Thu Mar 07 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.2.3-2
- Rebuild for Gromacs 4.6.1.

* Sun Feb 10 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.2.3-1
- Update to 1.2.3.

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.2.1-6
- Rebuild for Boost-1.53.0

* Wed Aug 15 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.1-5
- Bump spec due to boost update.

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-3
- Rebuilt for c++ ABI breakage

* Tue Jan 10 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.1-2
- Fix FTBFS on rawhide.

* Wed Nov 23 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.1-1.1
- Bump due to boost update.

* Thu Aug 25 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.1-1
- Update to 1.2.1.

* Sat Jul 23 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.1-3
- Bump spec due to new boost.

* Thu Apr 07 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.1-2
- Bump spec due to boost upgrade.

* Mon Feb 21 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.1-1
- Update to 1.1.

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Feb 06 2011 Thomas Spura <tomspur@fedoraproject.org> - 1.0.1-3
- rebuild for new boost

* Wed Dec 08 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0.1-2
- Fix spelling error in Requires of -devel, preserve timestamps upon install.

* Tue Dec 07 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0.1-1
- Update to 1.0.1.
- Added bash completion package.

* Thu Nov 25 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0-1
- First release.
